==> foundation-10.0.0.tgz: package/SocialDesignerNews/SocialDesignerNews.esm.js <==
import { __assign } from "tslib";
import * as React from 'react';
import { StyledIconBase } from '@styled-icons/styled-icon';
export var SocialDesignerNews = React.forwardRef(function (props, ref) {
    var attrs = {
        "fill": "currentColor",
        "xmlns": "http://www.w3.org/2000/svg",
    };
    return (React.createElement(StyledIconBase, __assign({ iconAttrs: attrs, iconVerticalAlign: "middle", iconViewBox: "0 0 100 100" }, props, { ref: ref }),
        React.createElement("g", { key: "k0" },
            React.createElement("path", { d: "M66.746 37.902l.261 15.744-9.164-14.804-.582-.94h-5.472v25.001h6.109l-.262-15.181 9.672 15.181h5.547V37.902h-6.109z" }),
            React.createElement("path", { d: "M79 14H21c-3.85 0-7 3.15-7 7v58c0 3.85 3.15 7 7 7h31.825L24.843 63.556V36.902h10.529c3.975 0 6.096.493 8.394 1.945 1.259.771 2.411 1.865 3.327 3.156.377.523.703 1.071.993 1.637l2.703 2.014v-8.753h7.029l.293.474.104.167 7.625 6.025-.094-5.65-.017-1.017h8.126v.01L86 46.753V21c0-3.85-3.15-7-7-7z" }),
            React.createElement("path", { d: "M40.842 38.546c-1.324-.434-2.861-.613-5-.636-.16-.002-.304-.008-.471-.008h-8.396v25.001h9.822c7.085 0 11.771-5.023 11.771-12.595 0-3.072-.75-5.586-2.286-7.721a11.302 11.302 0 00-.964-1.162c-.08-.086-.161-.172-.243-.256a10.696 10.696 0 00-.766-.695c-.102-.084-.201-.169-.305-.248a11.864 11.864 0 00-1.543-.984 10.38 10.38 0 00-.737-.357c-.017-.007-.033-.017-.05-.024a9.759 9.759 0 00-.832-.315zm1.351 11.95c0 4.387-2.136 6.786-6.109 6.786h-2.737V43.524h2.774c3.899 0 6.072 2.513 6.072 6.972z" }))));
});
SocialDesignerNews.displayName = 'SocialDesignerNews';
export var SocialDesignerNewsDimensions = { height: 24, width: 24 };

==> foundation-10.3.0.tgz: package/SocialDesignerNews/SocialDesignerNews.esm.js <==
import { __assign } from "tslib";
import * as React from 'react';
import { StyledIconBase } from '@styled-icons/styled-icon';
export var SocialDesignerNews = React.forwardRef(function (props, ref) {
    var attrs = {
        "fill": "currentColor",
        "xmlns": "http://www.w3.org/2000/svg",
    };
    return (React.createElement(StyledIconBase, __assign({ iconAttrs: attrs, iconVerticalAlign: "middle", iconViewBox: "0 0 100 100" }, props, { ref: ref }),
        React.createElement("g", null,
            React.createElement("path", { d: "M66.746 37.902l.261 15.744-9.164-14.804-.582-.94h-5.472v25.001h6.109l-.262-15.181 9.672 15.181h5.547V37.902h-6.109z" }),
            React.createElement("path", { d: "M79 14H21c-3.85 0-7 3.15-7 7v58c0 3.85 3.15 7 7 7h31.825L24.843 63.556V36.902h10.529c3.975 0 6.096.493 8.394 1.945 1.259.771 2.411 1.865 3.327 3.156.377.523.703 1.071.993 1.637l2.703 2.014v-8.753h7.029l.293.474.104.167 7.625 6.025-.094-5.65-.017-1.017h8.126v.01L86 46.753V21c0-3.85-3.15-7-7-7z" }),
            React.createElement("path", { d: "M40.842 38.546c-1.324-.434-2.861-.613-5-.636-.16-.002-.304-.008-.471-.008h-8.396v25.001h9.822c7.085 0 11.771-5.023 11.771-12.595 0-3.072-.75-5.586-2.286-7.721a11.302 11.302 0 00-.964-1.162c-.08-.086-.161-.172-.243-.256a10.696 10.696 0 00-.766-.695c-.102-.084-.201-.169-.305-.248a11.864 11.864 0 00-1.543-.984 10.38 10.38 0 00-.737-.357c-.017-.007-.033-.017-.05-.024a9.759 9.759 0 00-.832-.315zm1.351 11.95c0 4.387-2.136 6.786-6.109 6.786h-2.737V43.524h2.774c3.899 0 6.072 2.513 6.072 6.972z" }))));
});
SocialDesignerNews.displayName = 'SocialDesignerNews';
export var SocialDesignerNewsDimensions = { height: 100, width: 100 };
